@@ -73,10 +73,11 @@ class BrokenDependencies(Exception):
 
     - *deps*: List of unresolved dependencies.
     """
-    def __init__(self, deps):
+    def __init__(self, deps, broken):
         Exception.__init__(self)
         self.deps = deps
-    
+        self.broken = broken
+
 class InvalidFilter(Exception):
     """
     Exception called when someone try to use a invalid filter option.
@@ -479,6 +480,7 @@ def resolve_depends(from_list, with_lists, field=DEPENDS):
                 if depends:
                     if package not in broken:
                         broken.append(package)
+                        broken_depends[package["Package"]] = depends
                     return False
             
             for pkglist in with_lists:
@@ -514,9 +516,10 @@ def resolve_depends(from_list, with_lists, field=DEPENDS):
 
     # Broken packages
     broken = []
+    broken_depends = {}
     for package in from_list.values():
         calc_scores(package)
         select_field(package)
 
     if broken:
-        raise BrokenDependencies, broken
+        raise BrokenDependencies(broken, broken_depends)
